@@ -28,9 +28,9 @@
 //#undef PROTECT_WITH_INDEX
 //#undef UNPROTECT
 
-void string_to_try_Rf_error( const std::string& str) __attribute__ ((noreturn));
+void string_to_Rf_error( const std::string& str) __attribute__ ((noreturn));
 
-void exception_to_try_Rf_error( const std::exception& ex ) __attribute__ ((noreturn));
+void exception_to_Rf_error( const std::exception& ex ) __attribute__ ((noreturn));
 
 void getMatrixDims(SEXP r_theta, int *rows, int *cols);
 
