@@ -47,25 +47,26 @@ class omxExpectation {					// An Expectation
  public:
 	int numDataColumns;
 	SEXP rObj;
-        const char* expType;   // pointer to a static string, no need to allocate or free
+	const char *name;   // pointer to a static string, no need to allocate or free
 	omxData* data;
 	omxMatrix *thresholdsMat;
 	int numOrdinal;  // number of thresholds with matrix != 0
 	/* Replication of some of the structures from Matrix */
 	unsigned short isComplete;													// Whether or not this expectation has been initialize
 	omxState* currentState;
-	int expNum;
+	bool isClone() const;
+	int expNum;  // index in omxState's vector
 
 	// omxExpectation should not need to know about free variables.
 	FreeVarGroup *freeVarGroup; // TODO remove
-	const char *name;
 
 	bool canDuplicate;
 	bool dynamicDataSource;
 
-	omxExpectation() : dataColumnsPtr(0), numDataColumns(0), rObj(0), expType(0),
-		data(0), thresholdsMat(0), numOrdinal(0), isComplete(false), currentState(0),
-		expNum(0), freeVarGroup(0), name(0), canDuplicate(false), dynamicDataSource(false) {};
+	omxExpectation(omxState *state, int num) :
+		dataColumnsPtr(0), numDataColumns(0), rObj(0), name(0),
+		data(0), thresholdsMat(0), numOrdinal(0), isComplete(false), currentState(state),
+		expNum(num), freeVarGroup(0), canDuplicate(false), dynamicDataSource(false) {};
 	virtual ~omxExpectation() {};
 	virtual void init() {};
 	virtual void compute(FitContext *fc, const char *what, const char *how) = 0;
@@ -88,6 +89,7 @@ class omxExpectation {					// An Expectation
 	virtual bool usesDataColumnNames() const { return true; }
 	void loadFromR();
 	bool loadDefVars(int row);
+	void loadFakeDefVars();
 
 	void saveDataColumnsInfo(SEXP vec) {
 		numDataColumns = Rf_length(vec);
@@ -103,9 +105,6 @@ class omxExpectation {					// An Expectation
 	void loadThresholds();
 };
 
-omxExpectation *
-omxNewInternalExpectation(const char *expType, omxState* os);
-
 	void omxCompleteExpectation(omxExpectation *ox);
 
 	void omxFreeExpectationArgs(omxExpectation* Expectation);					// Frees all args
@@ -128,14 +127,14 @@ omxMatrix* omxGetExpectationComponent(omxExpectation *ox, const char* component)
 	
 void omxSetExpectationComponent(omxExpectation *ox, const char* component, omxMatrix *om);
 
-omxExpectation *omxInitNormalExpectation();
-omxExpectation *omxInitLISRELExpectation();
-omxExpectation *omxInitStateSpaceExpectation();
-omxExpectation *omxInitRAMExpectation();
-omxExpectation *omxInitExpectationBA81();
-omxExpectation *omxInitGREMLExpectation();
-omxExpectation *InitHiddenMarkovExpectation();
-omxExpectation *InitMixtureExpectation();
+omxExpectation *omxInitNormalExpectation(omxState *, int num);
+omxExpectation *omxInitLISRELExpectation(omxState *, int num);
+omxExpectation *omxInitStateSpaceExpectation(omxState *, int num);
+omxExpectation *omxInitRAMExpectation(omxState *, int num);
+omxExpectation *omxInitExpectationBA81(omxState *, int num);
+omxExpectation *omxInitGREMLExpectation(omxState *, int num);
+omxExpectation *InitHiddenMarkovExpectation(omxState *, int num);
+omxExpectation *InitMixtureExpectation(omxState *, int num);
 
 void complainAboutMissingMeans(omxExpectation *off);
 
