@@ -27,7 +27,7 @@ struct UnconstrainedObjective {
 	virtual double *getParamVec()=0;
 	virtual double getFit(const double *)=0;
 	virtual void getGrad(const double *, double *);
-	virtual void panic(const char *why) { stop("%s", why); };
+	virtual void panic(const char *why) { mxThrow("%s", why); };
 };
 
 class UnconstrainedSLSQPOptimizer {
